dengjen-tts-python 1.2.0

Python bindings for the dengjen-tts speech synthesis engine
docs.rs failed to build dengjen-tts-python-1.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

dengjen-tts-python

Python bindings to dengjen-tts using pyo3.